@@ -10,7 +10,7 @@ class ProjectModel(BaseModel):
     id: int
     name: str
     organisation: OrganisationModel
-    hide_disabled_flags: bool
+    hide_disabled_flags: bool = False
     segments: typing.List[SegmentModel] = Field(default_factory=list)
     enable_realtime_updates: bool = False
     server_key_only_feature_ids: typing.List[int] = Field(default_factory=list)
